synthetic_instrument_drop

Function synthetic_instrument_drop 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn synthetic_instrument_drop( synth: *mut SyntheticInstrument, )
Safety

synth must be a live owning pointer returned by synthetic_instrument_new, and must not be used after this call.

Panics

Panics if synth is null.